NAME
Mail::Box::Mbox::Message - one message in a Mbox folder
INHERITANCE
Mail::Box::Mbox::Message
is a Mail::Box::File::Message
is a Mail::Box::Message
is a Mail::Message
is a Mail::Reporter
SYNOPSIS
my $folder = new Mail::Box::Mbox folder => $ENV{MAIL}, ...;
my $message = $folder->message(0);
DESCRIPTION
Maintain one message in an Mail::Box::Mbox folder.
METHODS
Constructors
$obj->clone
See "Constructors" in Mail::Message
Mail::Box::Mbox::Message->coerce(MESSAGE)
See "METHODS" in Mail::Box::Message
Mail::Box::Mbox::Message->new(OPTIONS)
See "METHODS" in Mail::Box::File::Message
Constructing a message
$obj->bounce([RG-OBJECT|OPTIONS])
See "Constructing a message" in Mail::Message::Construct::Bounce
Mail::Box::Mbox::Message->build([MESSAGE|BODY], CONTENT)
See "Constructing a message" in Mail::Message::Construct::Build
Mail::Box::Mbox::Message->buildFromBody(BODY, [HEAD], HEADERS)
See "Constructing a message" in Mail::Message::Construct::Build
$obj->forward(OPTIONS)
See "Constructing a message" in Mail::Message::Construct::Forward
$obj->forwardPostlude
See "Constructing a message" in Mail::Message::Construct::Forward
$obj->forwardPrelude
See "Constructing a message" in Mail::Message::Construct::Forward
$obj->forwardSubject(STRING)
See "Constructing a message" in Mail::Message::Construct::Forward
Mail::Box::Mbox::Message->read(FILEHANDLE|SCALAR|REF-SCALAR|ARRAY-OF-LINES, OPTIONS)
See "Constructing a message" in Mail::Message::Construct::Read
$obj->rebuild(OPTIONS)
See "Constructing a message" in Mail::Message::Construct::Rebuild
$obj->reply(OPTIONS)
See "Constructing a message" in Mail::Message::Construct::Reply
$obj->replyPrelude([STRING|FIELD|ADDRESS])
See "Constructing a message" in Mail::Message::Construct::Reply
$obj->replySubject(STRING)
Mail::Box::Mbox::Message->replySubject(STRING)
See "Constructing a message" in Mail::Message::Construct::Reply
The Message
$obj->container
See "The Message" in Mail::Message
$obj->isDummy
See "The Message" in Mail::Message
$obj->isPart
See "The Message" in Mail::Message
$obj->messageId
See "The Message" in Mail::Message
$obj->print([FILEHANDLE])
See "The Message" in Mail::Message
$obj->send([MAILER], OPTIONS)
See "The Message" in Mail::Message
$obj->size
See "The Message" in Mail::Message
$obj->toplevel
See "The Message" in Mail::Message
$obj->write([FILEHANDLE])
See "METHODS" in Mail::Box::File::Message
The header
$obj->bcc
See "The header" in Mail::Message
$obj->cc
See "The header" in Mail::Message
$obj->date
See "The header" in Mail::Message
$obj->destinations
See "The header" in Mail::Message
$obj->from
See "The header" in Mail::Message
$obj->get(FIELDNAME)
See "The header" in Mail::Message
$obj->guessTimestamp
See "The header" in Mail::Message
$obj->head([HEAD])
See "The header" in Mail::Message
$obj->nrLines
See "The header" in Mail::Message
$obj->sender
See "The header" in Mail::Message
$obj->study(FIELDNAME)
See "The header" in Mail::Message
$obj->subject
See "The header" in Mail::Message
$obj->timestamp
See "The header" in Mail::Message
$obj->to
See "The header" in Mail::Message
The body
$obj->body([BODY])
See "The body" in Mail::Message
$obj->decoded(OPTIONS)
See "The body" in Mail::Message
$obj->encode(OPTIONS)
See "The body" in Mail::Message
$obj->isMultipart
See "The body" in Mail::Message
$obj->isNested
See "The body" in Mail::Message
$obj->parts(['ALL'|'ACTIVE'|'DELETED'|'RECURSE'|FILTER])
See "The body" in Mail::Message
The message
$obj->copyTo(FOLDER)
See "The message" in Mail::Box::Message
$obj->folder([FOLDER])
See "The message" in Mail::Box::Message
$obj->fromLine([LINE])
See "The message" in Mail::Box::File::Message
$obj->moveTo(FOLDER)
See "The message" in Mail::Box::Message
$obj->seqnr([INTEGER])
See "The message" in Mail::Box::Message
Flags
$obj->delete
See "Flags" in Mail::Box::Message
$obj->deleted([BOOLEAN])
See "Flags" in Mail::Box::Message
$obj->isDeleted
See "Flags" in Mail::Box::Message
$obj->isModified
$obj->label(LABEL [,VALUE [LABEL, VALUE] ])
$obj->labels
$obj->modified([BOOLEAN])
The whole message as text
$obj->file
See "The whole message as text" in Mail::Message::Construct::Text
$obj->lines
See "The whole message as text" in Mail::Message::Construct::Text
$obj->printStructure([FILEHANDLE][, INDENT])
See "The whole message as text" in Mail::Message::Construct::Text
$obj->string
See "The whole message as text" in Mail::Message::Construct::Text
Internals
$obj->diskDelete
See "Internals" in Mail::Box::Message
$obj->fileLocation
See "Internals" in Mail::Box::File::Message
$obj->isDelayed
See "Internals" in Mail::Message
$obj->loadBody
See "Internals" in Mail::Box::File::Message
$obj->moveLocation(DISTANCE)
See "Internals" in Mail::Box::File::Message
$obj->readBody(PARSER, HEAD [, BODYTYPE])
See "Internals" in Mail::Box::Message
$obj->readFromParser(PARSER)
See "Internals" in Mail::Box::File::Message
$obj->readHead(PARSER [,CLASS])
See "Internals" in Mail::Message
$obj->recursiveRebuildPart(PART, OPTIONS)
See "Internals" in Mail::Message::Construct::Rebuild
$obj->storeBody(BODY)
See "Internals" in Mail::Message
$obj->takeMessageId([STRING])
See "Internals" in Mail::Message
Error handling
$obj->AUTOLOAD
See "METHODS" in Mail::Message::Construct
$obj->defaultTrace([LEVEL, [LEVEL])
Mail::Box::Mbox::Message->defaultTrace([LEVEL, [LEVEL])
See "Error handling" in Mail::Reporter
$obj->errors
See "Error handling" in Mail::Reporter
$obj->log([LEVEL [,STRINGS]])
Mail::Box::Mbox::Message->log([LEVEL [,STRINGS]])
See "Error handling" in Mail::Reporter
$obj->logPriority(LEVEL)
Mail::Box::Mbox::Message->logPriority(LEVEL)
See "Error handling" in Mail::Reporter
$obj->logSettings
See "Error handling" in Mail::Reporter
$obj->notImplemented
See "Error handling" in Mail::Reporter
$obj->report([LEVEL])
See "Error handling" in Mail::Reporter
$obj->reportAll([LEVEL])
See "Error handling" in Mail::Reporter
$obj->shortSize([VALUE])
Mail::Box::Mbox::Message->shortSize([VALUE])
See "Error handling" in Mail::Message
$obj->shortString
See "Error handling" in Mail::Message
$obj->trace([LEVEL])
See "Error handling" in Mail::Reporter
$obj->warnings
See "Error handling" in Mail::Reporter
Cleanup
$obj->DESTROY
See "Cleanup" in Mail::Message
$obj->destruct
See "Cleanup" in Mail::Box::Message
$obj->inGlobalDestruction
See "Cleanup" in Mail::Reporter
Labels
$obj->labelsToStatus
When the labels were changed, that may effect the Status and/or X-Status header lines of mbox messages. Read about the relation between these fields and the labels in the DETAILS chapter.
The method will carefully only affect the result of modified() when there is a real change of flags, so not for each call to label().
$obj->statusToLabels
Update the labels according the status lines in the header. See the description in the DETAILS chapter.
DIAGNOSTICS
Error: Cannot include forward source as $include.
Unknown alternative for the forward(include). Valid choices are NO, INLINE, and ATTACH.
Error: Cannot include reply source as $include.
Unknown alternative for the include option of reply(). Valid choices are NO, INLINE, and ATTACH.
Error: No address to create forwarded to.
If a forward message is created, a destination address must be specified.
Error: No default mailer found to send message.
The message send() mechanism had not enough information to automatically find a mail transfer agent to sent this message. Specify a mailer explicitly using the via options.
Error: Package $package does not implement $method.
Fatal error: the specific package (or one of its superclasses) does not implement this method where it should. This message means that some other related classes do implement this method however the class at hand does not. Probably you should investigate this and probably inform the author of the package.
Error: Unable to read delayed body.
Error: no rebuild rule $name defined.
DETAILS
Labels
Status and X-Status fields
Mbox folders have no special means of storing information about messages (except the message separator line), and therefore have to revert to adding fields to the message header when something special comes up.
Most applications which can handle mbox folders support the Status and X-Status field convensions which are implemented by Mail::Box::Mbox. The following encoding is used:
Flag Field Label
R Status => seen (Read)
O Status => old (not recent)
A X-Status => replied (Answered)
F X-Status => flagged
There is no special flag for deleted, which most other folders support: messages flagged to be deleted will never be written to a folder file when it is closed.
REFERENCES
See the MailBox website at http://perl.overmeer.net/mailbox/ for more details.
COPYRIGHTS
Distribution version 2.044. Written by Mark Overmeer (mark@overmeer.net). See the ChangeLog for other contributors.
Copyright (c) 2001-2003 by the author(s). All rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.